@@ -42,7 +42,7 @@ spark_csv_read <- function(sc,
 
   options <- spark_csv_format_if_needed(read, sc)
 
-  if (sparklyr_boolean_option("sparklyr.verbose") && !identical(columns, NULL)) {
+  if (spark_config_value(sc$config, "sparklyr.verbose", FALSE) && !identical(columns, NULL)) {
     ncol_ds <- options %>%
       invoke(spark_csv_load_name(sc), path) %>%
       invoke("schema") %>%
@@ -53,11 +53,13 @@ spark_csv_read <- function(sc,
     }
   }
 
-  lapply(names(csvOptions), function(csvOptionName) {
-    options <<- invoke(options, "option", csvOptionName, csvOptions[[csvOptionName]])
-  })
+  for (csvOptionName in names(csvOptions)) {
+    options <- invoke(options, "option", csvOptionName, csvOptions[[csvOptionName]])
+  }
 
-  if (identical(columns, NULL)) {
+  columnsHaveTypes <- !identical(columns, NULL) && length(names(columns)) > 0
+
+  if (identical(columns, NULL) || !columnsHaveTypes) {
     optionSchema <- options
   }
   else {
@@ -65,10 +67,32 @@ spark_csv_read <- function(sc,
     optionSchema <- invoke(options, "schema", columnDefs)
   }
 
-  invoke(
+  df <- invoke(
     optionSchema,
     spark_csv_load_name(sc),
     path)
+
+  if ((identical(columns, NULL) && identical(csvOptions$header, "false")) ||
+      (!identical(columns, NULL) && !columnsHaveTypes)) {
+    if (!identical(columns, NULL)) {
+      newNames <- columns
+    }
+    else {
+      # create normalized column names when header = FALSE and a columns specification is not supplied
+      columns <- invoke(df, "columns")
+      n <- length(columns)
+      newNames <- sprintf("V%s", seq_len(n))
+    }
+    df <- invoke(df, "toDF", as.list(newNames))
+  } else {
+    # sanitize column names
+    colNames <- as.character(invoke(df, "columns"))
+    sanitized <- spark_sanitize_names(colNames, sc$config)
+    if (!identical(colNames, sanitized))
+      df <- invoke(df, "toDF", as.list(sanitized))
+  }
+
+  df
 }
 
 spark_csv_write <- function(df, path, csvOptions, mode, partition_by) {
@@ -77,9 +101,9 @@ spark_csv_write <- function(df, path, csvOptions, mode, partition_by) {
   write <- invoke(df, "write")
   options <- spark_csv_format_if_needed(write, sc)
 
-  lapply(names(csvOptions), function(csvOptionName) {
-    options <<- invoke(options, "option", csvOptionName, csvOptions[[csvOptionName]])
-  })
+  for (csvOptionName in names(csvOptions)) {
+    options <- invoke(options, "option", csvOptionName, csvOptions[[csvOptionName]])
+  }
 
   if (!is.null(partition_by))
     options <- invoke(options, "partitionBy", as.list(partition_by))
