@@ -1,4 +1,4 @@
-#' Feature Tranformation -- PCA (Estimator)
+#' Feature Transformation -- PCA (Estimator)
 #'
 #' PCA trains a model to project vectors to a lower dimensional space of the top k principal components.
 #'
@@ -9,22 +9,29 @@
 #' @param k The number of principal components
 #'
 #' @export
-ft_pca <- function(
-  x, input_col, output_col, k, dataset = NULL,
-  uid = random_string("pca_"), ...) {
+ft_pca <- function(x, input_col = NULL, output_col = NULL, k = NULL, dataset = NULL,
+                   uid = random_string("pca_"), ...) {
   UseMethod("ft_pca")
 }
 
 #' @export
-ft_pca.spark_connection <- function(
-  x, input_col, output_col, k, dataset = NULL,
-  uid = random_string("pca_"), ...) {
+ft_pca.spark_connection <- function(x, input_col = NULL, output_col = NULL, k = NULL, dataset = NULL,
+                                    uid = random_string("pca_"), ...) {
 
-  ml_ratify_args()
+  .args <- list(
+    input_col = input_col,
+    output_col = output_col,
+    k = k,
+    uid = uid
+  ) %>%
+    c(rlang::dots_list(...)) %>%
+    ml_validator_pca()
 
-  estimator <- ml_new_transformer(x, "org.apache.spark.ml.feature.PCA",
-                                  input_col, output_col, uid) %>%
-    invoke("setK", k) %>%
+  estimator <- ml_new_transformer(
+    x, "org.apache.spark.ml.feature.PCA",
+    input_col = .args[["input_col"]], output_col = .args[["output_col"]], uid = .args[["uid"]]
+  ) %>%
+    maybe_set_param("setK", .args[["k"]]) %>%
     new_ml_pca()
 
   if (is.null(dataset))
@@ -34,42 +41,42 @@ ft_pca.spark_connection <- function(
 }
 
 #' @export
-ft_pca.ml_pipeline <- function(
-  x, input_col, output_col, k, dataset = NULL,
-  uid = random_string("pca_"), ...
-) {
+ft_pca.ml_pipeline <- function(x, input_col = NULL, output_col = NULL, k = NULL, dataset = NULL,
+                               uid = random_string("pca_"), ...) {
 
-  stage <- ml_new_stage_modified_args()
+  stage <- ft_pca.spark_connection(
+    x = spark_connection(x),
+    input_col = input_col,
+    output_col = output_col,
+    k = k,
+    dataset = dataset,
+    uid = uid,
+    ...
+  )
   ml_add_stage(x, stage)
 
 }
 
 #' @export
-ft_pca.tbl_spark <- function(
-  x, input_col, output_col, k, dataset = NULL,
-  uid = random_string("pca_"), ...
-) {
-  stage <- ml_new_stage_modified_args()
+ft_pca.tbl_spark <- function(x, input_col = NULL, output_col = NULL, k = NULL, dataset = NULL,
+                             uid = random_string("pca_"), ...) {
+
+  stage <- ft_pca.spark_connection(
+    x = spark_connection(x),
+    input_col = input_col,
+    output_col = output_col,
+    k = k,
+    dataset = dataset,
+    uid = uid,
+    ...
+  )
 
   if (is_ml_transformer(stage))
     ml_transform(stage, x)
   else
     ml_fit_and_transform(stage, x)
 }
-# Validator
 
-ml_validator_pca <- function(args, nms) {
-  args %>%
-    ml_validate_args(
-      {
-        k <- ensure_scalar_integer(k)
-      }) %>%
-    ml_extract_args(nms)
-}
-
-
-# Constructors
-#
 new_ml_pca <- function(jobj) {
   new_ml_estimator(jobj, subclass = "ml_pca")
 }
@@ -82,6 +89,13 @@ new_ml_pca_model <- function(jobj) {
     subclass = "ml_pca_model")
 }
 
+ml_validator_pca <- function(.args) {
+  .args <- validate_args_transformer(.args)
+  .args[["k"]] <- cast_nullable_scalar_integer(.args[["k"]])
+  .args
+}
+
+
 #' @rdname ft_pca
 #' @param features The columns to use in the principal components
 #'   analysis. Defaults to all columns in \code{x}.
@@ -110,7 +124,7 @@ ml_pca <- function(x,
                    pc_prefix = "PC",
                    ...)
 {
-  k <- ensure_scalar_integer(k)
+  k <- cast_scalar_integer(k)
 
   sc <- spark_connection(x)
 
