@@ -8,11 +8,12 @@ object LivyUtils {
     "Logger" -> new Logger("", 0),
     "SQLUtils" -> SQLUtils,
     "Utils" -> Utils,
+    "Repartition" -> Repartition,
     "ApplyUtils" -> ApplyUtils,
     "WorkerHelper" -> WorkerHelper,
     "WorkerUtils" -> WorkerUtils,
     "MLUtils" -> MLUtils,
-    "Shell" -> Shell
+    "MLUtils2" -> MLUtils2
    )
 
   val tracker = new JVMObjectTracker()
